==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/eventing/v1beta1/EventTypeStatusFluent.java <==
package io.fabric8.knative.eventing.v1beta1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface EventTypeStatusFluent<A extends EventTypeStatusFluent<A>> extends Fluent<A> {


    public A addToAnnotations(String key,String value);
    public A addToAnnotations(Map<String,String> map);
    public A removeFromAnnotations(String key);
    public A removeFromAnnotations(Map<String,String> map);
    public Map<String,String> getAnnotations();
    public <K extends Object,V extends Object>A withAnnotations(Map<String,String> annotations);
    public Boolean hasAnnotations();
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public EventTypeStatusFluent.ConditionsNested<A> addNewCondition();
    public EventTypeStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public EventTypeStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public EventTypeStatusFluent.ConditionsNested<A> editCondition(int index);
    public EventTypeStatusFluent.ConditionsNested<A> editFirstCondition();
    public EventTypeStatusFluent.ConditionsNested<A> editLastCondition();
    public EventTypeStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A withNewObservedGeneration(long arg1);
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<EventTypeStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


}

==> knative-model-5.3.1-sources.jar: annotations/io/fabric8/knative/eventing/v1beta1/EventTypeStatusFluent.java <==
package io.fabric8.knative.eventing.v1beta1;

import io.fabric8.knative.internal.pkg.apis.Condition;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.ConditionFluent;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.knative.internal.pkg.apis.ConditionBuilder;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface EventTypeStatusFluent<A extends EventTypeStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public A addToAnnotations(String key,String value);
    public A addToAnnotations(java.util.Map<String,String> map);
    public A removeFromAnnotations(String key);
    public A removeFromAnnotations(java.util.Map<String,String> map);
    public java.util.Map<String,String> getAnnotations();
    public <K extends Object,V extends Object>A withAnnotations(java.util.Map<String,String> annotations);
    public Boolean hasAnnotations();
    public A addToConditions(int index,Condition item);
    public A setToConditions(int index,Condition item);
    public A addToConditions(Condition... items);
    public A addAllToConditions(Collection<Condition> items);
    public A removeFromConditions(Condition... items);
    public A removeAllFromConditions(Collection<Condition> items);
    public A removeMatchingFromConditions(Predicate<ConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<Condition> getConditions();
    public List<Condition> buildConditions();
    public Condition buildCondition(int index);
    public Condition buildFirstCondition();
    public Condition buildLastCondition();
    public Condition buildMatchingCondition(Predicate<ConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<ConditionBuilder> predicate);
    public A withConditions(List<Condition> conditions);
    public A withConditions(Condition... conditions);
    public Boolean hasConditions();
    public io.fabric8.knative.eventing.v1beta1.EventTypeStatusFluent.ConditionsNested<A> addNewCondition();
    public io.fabric8.knative.eventing.v1beta1.EventTypeStatusFluent.ConditionsNested<A> addNewConditionLike(Condition item);
    public io.fabric8.knative.eventing.v1beta1.EventTypeStatusFluent.ConditionsNested<A> setNewConditionLike(int index,Condition item);
    public io.fabric8.knative.eventing.v1beta1.EventTypeStatusFluent.ConditionsNested<A> editCondition(int index);
    public io.fabric8.knative.eventing.v1beta1.EventTypeStatusFluent.ConditionsNested<A> editFirstCondition();
    public io.fabric8.knative.eventing.v1beta1.EventTypeStatusFluent.ConditionsNested<A> editLastCondition();
    public io.fabric8.knative.eventing.v1beta1.EventTypeStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<ConditionBuilder> predicate);
    public Long getObservedGeneration();
    public A withObservedGeneration(Long observedGeneration);
    public Boolean hasObservedGeneration();
    public A withNewObservedGeneration(long arg1);
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ConditionFluent<io.fabric8.knative.eventing.v1beta1.EventTypeStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


}
